window.Gleam.initSearch([{"doc":"oas","title":"oas","content":"# oas\n\nParse an open api (previously swagger) spec.\n\n[![Package Version](https://img.shields.io/hexpm/v/oas)](https://hex.pm/packages/oas)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/oas/)\n\n```sh\ngleam add oas@1\n```\n\nThe `oas` library provides a decoder that is designed to be used with JSON or YAML.\n\n```gleam\nimport gleam/json\nimport oas\n\npub fn main() {\n  let raw = todo as &quot;some schema content&quot;\n  let result = json.decode(raw, oas.decoder)\n  case result {\n    Ok(oas.Document(paths: paths, components: components, ..)) -&gt; {\n      // use oas spec\n    }\n    Error(_) -&gt; panic as &quot;could not decode&quot;\n  }\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/oas&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n\n## Missing features\n\nThe following have not been present in the API&#39;s I have worked with.\nNotably security is usually described in human readable language as part of API docs.\n\nContributions to add these are welcome. They will not require a breaking change to upgrade so I am committing to a 1.0 release\n\n- Webhooks\n- external docs\n- security schemas\n\n## Credit\n\nCreated for [EYG](https://eyg.run/), a new integration focused programming language.","url":"index.html"},{"doc":"oas","title":"Components","content":"pub type Components {\n  Components(\n    schemas: Dict(String, Schema),\n    responses: Dict(String, Ref(Response)),\n    parameters: Dict(String, Ref(Parameter)),\n    request_bodies: Dict(String, Ref(RequestBody)),\n  )\n}\n Holds a set of reusable objects for different aspects of the OAS.\n All objects defined within the components object will have no effect on the API unless they are explicitly referenced from properties outside the components object.\nComponents(\n  schemas: Dict(String, Schema),\n  responses: Dict(String, Ref(Response)),\n  parameters: Dict(String, Ref(Parameter)),\n  request_bodies: Dict(String, Ref(RequestBody)),\n)\n\n\nSynonyms:\noas.Components\noas Components","url":"oas.html#Components"},{"doc":"oas","title":"Contact","content":"pub type Contact {\n  Contact(\n    name: Option(String),\n    url: Option(String),\n    email: Option(String),\n  )\n}\n Contact information for the exposed API.\nContact(\n  name: Option(String),\n  url: Option(String),\n  email: Option(String),\n)\n\n\nSynonyms:\noas.Contact\noas Contact","url":"oas.html#Contact"},{"doc":"oas","title":"Document","content":"pub type Document {\n  Document(\n    openapi: String,\n    info: Info,\n    json_schema_dialect: Option(String),\n    servers: List(Server),\n    paths: Dict(String, PathItem),\n    components: Components,\n  )\n}\n This is the root object of the OpenAPI document.\nDocument(\n  openapi: String,\n  info: Info,\n  json_schema_dialect: Option(String),\n  servers: List(Server),\n  paths: Dict(String, PathItem),\n  components: Components,\n)\n\n\nSynonyms:\noas.Document\noas Document","url":"oas.html#Document"},{"doc":"oas","title":"Header","content":"pub type Header {\n  Header(\n    description: Option(String),\n    required: Bool,\n    schema: Schema,\n  )\n}\n\nHeader(\n  description: Option(String),\n  required: Bool,\n  schema: Schema,\n)\n\n\nSynonyms:\noas.Header\noas Header","url":"oas.html#Header"},{"doc":"oas","title":"Info","content":"pub type Info {\n  Info(\n    title: String,\n    summary: Option(String),\n    description: Option(String),\n    terms_of_service: Option(String),\n    contact: Option(Contact),\n    license: Option(Licence),\n    version: String,\n  )\n}\n The object provides metadata about the API. The metadata MAY be used by the clients if needed, and MAY be presented in editing or documentation generation tools for convenience.\nInfo(\n  title: String,\n  summary: Option(String),\n  description: Option(String),\n  terms_of_service: Option(String),\n  contact: Option(Contact),\n  license: Option(Licence),\n  version: String,\n)\n\n\nSynonyms:\noas.Info\noas Info","url":"oas.html#Info"},{"doc":"oas","title":"Licence","content":"pub type Licence {\n  Licence(\n    name: String,\n    identifier: Option(String),\n    url: Option(String),\n  )\n}\n License information for the exposed API.\nLicence(\n  name: String,\n  identifier: Option(String),\n  url: Option(String),\n)\n\n\nSynonyms:\noas.Licence\noas Licence","url":"oas.html#Licence"},{"doc":"oas","title":"MediaType","content":"pub type MediaType {\n  MediaType(schema: Ref(Schema))\n}\n Each Media Type Object provides schema and examples for the media type identified by its key.\nMediaType(schema: Ref(Schema))\n\n\nSynonyms:\noas.MediaType\noas MediaType","url":"oas.html#MediaType"},{"doc":"oas","title":"Operation","content":"pub type Operation {\n  Operation(\n    tags: List(String),\n    summary: Option(String),\n    description: Option(String),\n    operation_id: String,\n    parameters: List(Ref(Parameter)),\n    request_body: Option(Ref(RequestBody)),\n    responses: Dict(Status, Ref(Response)),\n  )\n}\n Describes a single API operation on a path.\nOperation(\n  tags: List(String),\n  summary: Option(String),\n  description: Option(String),\n  operation_id: String,\n  parameters: List(Ref(Parameter)),\n  request_body: Option(Ref(RequestBody)),\n  responses: Dict(Status, Ref(Response)),\n)\n\n\nSynonyms:\noas.Operation\noas Operation","url":"oas.html#Operation"},{"doc":"oas","title":"Parameter","content":"pub type Parameter {\n  QueryParameter(\n    name: String,\n    description: Option(String),\n    required: Bool,\n    schema: Ref(Schema),\n  )\n  PathParameter(name: String, schema: Ref(Schema))\n  HeaderParameter(\n    name: String,\n    description: Option(String),\n    required: Bool,\n    schema: Ref(Schema),\n  )\n  CookieParameter(\n    name: String,\n    description: Option(String),\n    required: Bool,\n    schema: Ref(Schema),\n  )\n}\n Describes a single operation parameter.\n\n There are four possible parameter locations specified by the `in` field:\n `path`, `query`, `header` and `cookie`.\n A unique parameter is defined by a combination of a name and location.\nQueryParameter(\n  name: String,\n  description: Option(String),\n  required: Bool,\n  schema: Ref(Schema),\n)\n\n\nPathParameter(name: String, schema: Ref(Schema))\n\n\nHeaderParameter(\n  name: String,\n  description: Option(String),\n  required: Bool,\n  schema: Ref(Schema),\n)\n\n\nCookieParameter(\n  name: String,\n  description: Option(String),\n  required: Bool,\n  schema: Ref(Schema),\n)\n\n\nSynonyms:\noas.Parameter\noas Parameter","url":"oas.html#Parameter"},{"doc":"oas","title":"PathItem","content":"pub type PathItem {\n  PathItem(\n    summary: Option(String),\n    description: Option(String),\n    parameters: List(Ref(Parameter)),\n    operations: List(#(http.Method, Operation)),\n  )\n}\n Describes the operations available on a single path.\nPathItem(\n  summary: Option(String),\n  description: Option(String),\n  parameters: List(Ref(Parameter)),\n  operations: List(#(http.Method, Operation)),\n)\n\n\nSynonyms:\noas.PathItem\noas PathItem","url":"oas.html#PathItem"},{"doc":"oas","title":"Ref","content":"pub type Ref(t) {\n  Ref(\n    ref: String,\n    summary: Option(String),\n    description: Option(String),\n  )\n  Inline(value: t)\n}\n Node in the Specification that might be represented by a reference.\nRef(\n  ref: String,\n  summary: Option(String),\n  description: Option(String),\n)\n\n\nInline(value: t)\n\n\nSynonyms:\noas.Ref\noas Ref","url":"oas.html#Ref"},{"doc":"oas","title":"RequestBody","content":"pub type RequestBody {\n  RequestBody(\n    description: Option(String),\n    content: Dict(String, MediaType),\n    required: Bool,\n  )\n}\n Describes a single request body.\nRequestBody(\n  description: Option(String),\n  content: Dict(String, MediaType),\n  required: Bool,\n)\n\n\nSynonyms:\noas.RequestBody\noas RequestBody","url":"oas.html#RequestBody"},{"doc":"oas","title":"Response","content":"pub type Response {\n  Response(\n    description: Option(String),\n    headers: Dict(String, Ref(Header)),\n    content: Dict(String, MediaType),\n  )\n}\n Describes a single response from an API Operation\nResponse(\n  description: Option(String),\n  headers: Dict(String, Ref(Header)),\n  content: Dict(String, MediaType),\n)\n\n\nSynonyms:\noas.Response\noas Response","url":"oas.html#Response"},{"doc":"oas","title":"Schema","content":"pub type Schema {\n  Boolean\n  Integer\n  Number\n  String\n  Array(Ref(Schema))\n  Object(properties: Dict(String, Ref(Schema)))\n  AllOf(List(Ref(Dict(String, Ref(Schema)))))\n  AnyOf(List(Ref(Schema)))\n  OneOf(List(Ref(Schema)))\n}\n Represents a decoded JSON schema.\nBoolean\n\n\nInteger\n\n\nNumber\n\n\nString\n\n\nArray(Ref(Schema))\n\n\nObject(properties: Dict(String, Ref(Schema)))\n\n\nAllOf(List(Ref(Dict(String, Ref(Schema)))))\n\n\nAnyOf(List(Ref(Schema)))\n\n\nOneOf(List(Ref(Schema)))\n\n\nSynonyms:\noas.Schema\noas Schema","url":"oas.html#Schema"},{"doc":"oas","title":"Segment","content":"pub type Segment {\n  FixedSegment(content: String)\n  MatchSegment(name: String, schema: Schema)\n}\n\nFixedSegment(content: String)\n\n\nMatchSegment(name: String, schema: Schema)\n\n\nSynonyms:\noas.Segment\noas Segment","url":"oas.html#Segment"},{"doc":"oas","title":"Server","content":"pub type Server {\n  Server(\n    url: String,\n    description: Option(String),\n    variables: Dict(String, ServerVariable),\n  )\n}\n An object representing a Server.\nServer(\n  url: String,\n  description: Option(String),\n  variables: Dict(String, ServerVariable),\n)\n\n\nSynonyms:\noas.Server\noas Server","url":"oas.html#Server"},{"doc":"oas","title":"ServerVariable","content":"pub type ServerVariable {\n  ServerVariable(\n    enum: List(String),\n    default: String,\n    description: Option(String),\n  )\n}\n An object representing a Server Variable for server URL template substitution.\nServerVariable(\n  enum: List(String),\n  default: String,\n  description: Option(String),\n)\n\n\nSynonyms:\noas.ServerVariable\noas ServerVariable","url":"oas.html#ServerVariable"},{"doc":"oas","title":"Status","content":"pub type Status {\n  Default\n  Status(Int)\n}\n\nDefault\n\n\nStatus(Int)\n\n\nSynonyms:\noas.Status\noas Status","url":"oas.html#Status"},{"doc":"oas","title":"decoder","content":"pub fn decoder(\n  top: Dynamic,\n) -&gt; Result(Document, List(DecodeError))\n\nSynonyms:\noas.decoder\noas decoder","url":"oas.html#decoder"},{"doc":"oas","title":"fetch_parameter","content":"pub fn fetch_parameter(\n  ref: Ref(a),\n  parameters: Dict(String, Ref(a)),\n) -&gt; a\n\nSynonyms:\noas.fetch_parameter\noas fetch_parameter","url":"oas.html#fetch_parameter"},{"doc":"oas","title":"fetch_request_body","content":"pub fn fetch_request_body(\n  ref: Ref(a),\n  request_bodies: Dict(String, Ref(a)),\n) -&gt; a\n\nSynonyms:\noas.fetch_request_body\noas fetch_request_body","url":"oas.html#fetch_request_body"},{"doc":"oas","title":"fetch_response","content":"pub fn fetch_response(\n  ref: Ref(a),\n  responses: Dict(String, Ref(a)),\n) -&gt; a\n\nSynonyms:\noas.fetch_response\noas fetch_response","url":"oas.html#fetch_response"},{"doc":"oas","title":"fetch_schema","content":"pub fn fetch_schema(ref: Ref(a), schemas: Dict(String, a)) -&gt; a\n\nSynonyms:\noas.fetch_schema\noas fetch_schema","url":"oas.html#fetch_schema"},{"doc":"oas","title":"gather_match","content":"pub fn gather_match(\n  pattern: String,\n  parameters: List(Parameter),\n  components: Components,\n) -&gt; Result(List(Segment), Nil)\n\nSynonyms:\noas.gather_match\noas gather_match","url":"oas.html#gather_match"},{"doc":"oas","title":"query_parameters","content":"pub fn query_parameters(\n  parameters: List(Parameter),\n) -&gt; List(#(String, Bool, Ref(Schema)))\n\nSynonyms:\noas.query_parameters\noas query_parameters","url":"oas.html#query_parameters"},{"doc":"oas","title":"oas","content":"","url":"oas.html"}]);